valuta.currencies package
=========================

Submodules
----------

valuta.currencies.aed module
----------------------------

.. automodule:: valuta.currencies.aed
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.afn module
----------------------------

.. automodule:: valuta.currencies.afn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.all module
----------------------------

.. automodule:: valuta.currencies.all
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.amd module
----------------------------

.. automodule:: valuta.currencies.amd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ang module
----------------------------

.. automodule:: valuta.currencies.ang
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.aoa module
----------------------------

.. automodule:: valuta.currencies.aoa
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ars module
----------------------------

.. automodule:: valuta.currencies.ars
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.aud module
----------------------------

.. automodule:: valuta.currencies.aud
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.awg module
----------------------------

.. automodule:: valuta.currencies.awg
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.azn module
----------------------------

.. automodule:: valuta.currencies.azn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bam module
----------------------------

.. automodule:: valuta.currencies.bam
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bbd module
----------------------------

.. automodule:: valuta.currencies.bbd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bdt module
----------------------------

.. automodule:: valuta.currencies.bdt
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bgn module
----------------------------

.. automodule:: valuta.currencies.bgn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bhd module
----------------------------

.. automodule:: valuta.currencies.bhd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bif module
----------------------------

.. automodule:: valuta.currencies.bif
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bmd module
----------------------------

.. automodule:: valuta.currencies.bmd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bnd module
----------------------------

.. automodule:: valuta.currencies.bnd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bob module
----------------------------

.. automodule:: valuta.currencies.bob
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.brl module
----------------------------

.. automodule:: valuta.currencies.brl
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bsd module
----------------------------

.. automodule:: valuta.currencies.bsd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.btc module
----------------------------

.. automodule:: valuta.currencies.btc
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.btn module
----------------------------

.. automodule:: valuta.currencies.btn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bwp module
----------------------------

.. automodule:: valuta.currencies.bwp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.byn module
----------------------------

.. automodule:: valuta.currencies.byn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.bzd module
----------------------------

.. automodule:: valuta.currencies.bzd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cad module
----------------------------

.. automodule:: valuta.currencies.cad
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cdf module
----------------------------

.. automodule:: valuta.currencies.cdf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.chf module
----------------------------

.. automodule:: valuta.currencies.chf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ckd module
----------------------------

.. automodule:: valuta.currencies.ckd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.clp module
----------------------------

.. automodule:: valuta.currencies.clp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cny module
----------------------------

.. automodule:: valuta.currencies.cny
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cop module
----------------------------

.. automodule:: valuta.currencies.cop
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.crc module
----------------------------

.. automodule:: valuta.currencies.crc
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cup module
----------------------------

.. automodule:: valuta.currencies.cup
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.cve module
----------------------------

.. automodule:: valuta.currencies.cve
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.czk module
----------------------------

.. automodule:: valuta.currencies.czk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.djf module
----------------------------

.. automodule:: valuta.currencies.djf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.dkk module
----------------------------

.. automodule:: valuta.currencies.dkk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.dop module
----------------------------

.. automodule:: valuta.currencies.dop
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.dzd module
----------------------------

.. automodule:: valuta.currencies.dzd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.egp module
----------------------------

.. automodule:: valuta.currencies.egp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ern module
----------------------------

.. automodule:: valuta.currencies.ern
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.etb module
----------------------------

.. automodule:: valuta.currencies.etb
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.eur module
----------------------------

.. automodule:: valuta.currencies.eur
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.fjd module
----------------------------

.. automodule:: valuta.currencies.fjd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.fkp module
----------------------------

.. automodule:: valuta.currencies.fkp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.fok module
----------------------------

.. automodule:: valuta.currencies.fok
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gbp module
----------------------------

.. automodule:: valuta.currencies.gbp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gel module
----------------------------

.. automodule:: valuta.currencies.gel
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ggp module
----------------------------

.. automodule:: valuta.currencies.ggp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ghs module
----------------------------

.. automodule:: valuta.currencies.ghs
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gip module
----------------------------

.. automodule:: valuta.currencies.gip
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gmd module
----------------------------

.. automodule:: valuta.currencies.gmd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gnf module
----------------------------

.. automodule:: valuta.currencies.gnf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gtq module
----------------------------

.. automodule:: valuta.currencies.gtq
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.gyd module
----------------------------

.. automodule:: valuta.currencies.gyd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.hkd module
----------------------------

.. automodule:: valuta.currencies.hkd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.hnl module
----------------------------

.. automodule:: valuta.currencies.hnl
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.hrk module
----------------------------

.. automodule:: valuta.currencies.hrk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.htg module
----------------------------

.. automodule:: valuta.currencies.htg
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.huf module
----------------------------

.. automodule:: valuta.currencies.huf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.idr module
----------------------------

.. automodule:: valuta.currencies.idr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ils module
----------------------------

.. automodule:: valuta.currencies.ils
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.imp module
----------------------------

.. automodule:: valuta.currencies.imp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.inr module
----------------------------

.. automodule:: valuta.currencies.inr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.iqd module
----------------------------

.. automodule:: valuta.currencies.iqd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.irr module
----------------------------

.. automodule:: valuta.currencies.irr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.isk module
----------------------------

.. automodule:: valuta.currencies.isk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.jep module
----------------------------

.. automodule:: valuta.currencies.jep
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.jmd module
----------------------------

.. automodule:: valuta.currencies.jmd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.jod module
----------------------------

.. automodule:: valuta.currencies.jod
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.jpy module
----------------------------

.. automodule:: valuta.currencies.jpy
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kes module
----------------------------

.. automodule:: valuta.currencies.kes
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kgs module
----------------------------

.. automodule:: valuta.currencies.kgs
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.khr module
----------------------------

.. automodule:: valuta.currencies.khr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kid module
----------------------------

.. automodule:: valuta.currencies.kid
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kmf module
----------------------------

.. automodule:: valuta.currencies.kmf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kpw module
----------------------------

.. automodule:: valuta.currencies.kpw
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.krw module
----------------------------

.. automodule:: valuta.currencies.krw
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kwd module
----------------------------

.. automodule:: valuta.currencies.kwd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kyd module
----------------------------

.. automodule:: valuta.currencies.kyd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.kzt module
----------------------------

.. automodule:: valuta.currencies.kzt
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lak module
----------------------------

.. automodule:: valuta.currencies.lak
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lbp module
----------------------------

.. automodule:: valuta.currencies.lbp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lkr module
----------------------------

.. automodule:: valuta.currencies.lkr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lrd module
----------------------------

.. automodule:: valuta.currencies.lrd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lsl module
----------------------------

.. automodule:: valuta.currencies.lsl
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.lyd module
----------------------------

.. automodule:: valuta.currencies.lyd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mad module
----------------------------

.. automodule:: valuta.currencies.mad
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mdl module
----------------------------

.. automodule:: valuta.currencies.mdl
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mga module
----------------------------

.. automodule:: valuta.currencies.mga
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mkd module
----------------------------

.. automodule:: valuta.currencies.mkd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mmk module
----------------------------

.. automodule:: valuta.currencies.mmk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mnt module
----------------------------

.. automodule:: valuta.currencies.mnt
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mop module
----------------------------

.. automodule:: valuta.currencies.mop
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mru module
----------------------------

.. automodule:: valuta.currencies.mru
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mur module
----------------------------

.. automodule:: valuta.currencies.mur
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mvr module
----------------------------

.. automodule:: valuta.currencies.mvr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mwk module
----------------------------

.. automodule:: valuta.currencies.mwk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mxn module
----------------------------

.. automodule:: valuta.currencies.mxn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.myr module
----------------------------

.. automodule:: valuta.currencies.myr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.mzn module
----------------------------

.. automodule:: valuta.currencies.mzn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.nad module
----------------------------

.. automodule:: valuta.currencies.nad
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ngn module
----------------------------

.. automodule:: valuta.currencies.ngn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.nio module
----------------------------

.. automodule:: valuta.currencies.nio
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.nok module
----------------------------

.. automodule:: valuta.currencies.nok
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.npr module
----------------------------

.. automodule:: valuta.currencies.npr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.nzd module
----------------------------

.. automodule:: valuta.currencies.nzd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.omr module
----------------------------

.. automodule:: valuta.currencies.omr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pab module
----------------------------

.. automodule:: valuta.currencies.pab
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pen module
----------------------------

.. automodule:: valuta.currencies.pen
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pgk module
----------------------------

.. automodule:: valuta.currencies.pgk
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.php module
----------------------------

.. automodule:: valuta.currencies.php
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pkr module
----------------------------

.. automodule:: valuta.currencies.pkr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pln module
----------------------------

.. automodule:: valuta.currencies.pln
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pnd module
----------------------------

.. automodule:: valuta.currencies.pnd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.prb module
----------------------------

.. automodule:: valuta.currencies.prb
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.pyg module
----------------------------

.. automodule:: valuta.currencies.pyg
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.qar module
----------------------------

.. automodule:: valuta.currencies.qar
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ron module
----------------------------

.. automodule:: valuta.currencies.ron
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.rsd module
----------------------------

.. automodule:: valuta.currencies.rsd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.rub module
----------------------------

.. automodule:: valuta.currencies.rub
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.rwf module
----------------------------

.. automodule:: valuta.currencies.rwf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sar module
----------------------------

.. automodule:: valuta.currencies.sar
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sbd module
----------------------------

.. automodule:: valuta.currencies.sbd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.scr module
----------------------------

.. automodule:: valuta.currencies.scr
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sdg module
----------------------------

.. automodule:: valuta.currencies.sdg
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sek module
----------------------------

.. automodule:: valuta.currencies.sek
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sgd module
----------------------------

.. automodule:: valuta.currencies.sgd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.shp module
----------------------------

.. automodule:: valuta.currencies.shp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sll module
----------------------------

.. automodule:: valuta.currencies.sll
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sls module
----------------------------

.. automodule:: valuta.currencies.sls
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.sos module
----------------------------

.. automodule:: valuta.currencies.sos
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.srd module
----------------------------

.. automodule:: valuta.currencies.srd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ssp module
----------------------------

.. automodule:: valuta.currencies.ssp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.stn module
----------------------------

.. automodule:: valuta.currencies.stn
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.syp module
----------------------------

.. automodule:: valuta.currencies.syp
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.szl module
----------------------------

.. automodule:: valuta.currencies.szl
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.thb module
----------------------------

.. automodule:: valuta.currencies.thb
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.tjs module
----------------------------

.. automodule:: valuta.currencies.tjs
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.tmt module
----------------------------

.. automodule:: valuta.currencies.tmt
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.tnd module
----------------------------

.. automodule:: valuta.currencies.tnd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.top module
----------------------------

.. automodule:: valuta.currencies.top
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.try module
----------------------------

.. automodule:: valuta.currencies.try
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ttd module
----------------------------

.. automodule:: valuta.currencies.ttd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.tvd module
----------------------------

.. automodule:: valuta.currencies.tvd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.twd module
----------------------------

.. automodule:: valuta.currencies.twd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.tzs module
----------------------------

.. automodule:: valuta.currencies.tzs
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.uah module
----------------------------

.. automodule:: valuta.currencies.uah
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ugx module
----------------------------

.. automodule:: valuta.currencies.ugx
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.usd module
----------------------------

.. automodule:: valuta.currencies.usd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.uyu module
----------------------------

.. automodule:: valuta.currencies.uyu
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.uzs module
----------------------------

.. automodule:: valuta.currencies.uzs
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.ves module
----------------------------

.. automodule:: valuta.currencies.ves
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.vnd module
----------------------------

.. automodule:: valuta.currencies.vnd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.vuv module
----------------------------

.. automodule:: valuta.currencies.vuv
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.wst module
----------------------------

.. automodule:: valuta.currencies.wst
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.xaf module
----------------------------

.. automodule:: valuta.currencies.xaf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.xcd module
----------------------------

.. automodule:: valuta.currencies.xcd
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.xof module
----------------------------

.. automodule:: valuta.currencies.xof
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.xpf module
----------------------------

.. automodule:: valuta.currencies.xpf
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.yer module
----------------------------

.. automodule:: valuta.currencies.yer
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.zar module
----------------------------

.. automodule:: valuta.currencies.zar
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.zmw module
----------------------------

.. automodule:: valuta.currencies.zmw
   :members:
   :undoc-members:
   :show-inheritance:

valuta.currencies.zwb module
----------------------------

.. automodule:: valuta.currencies.zwb
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: valuta.currencies
   :members:
   :undoc-members:
   :show-inheritance:
